==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/9c/9cbc109bd797c329128b42dd981af498.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Scheduler/Option/ExportOption.php */
class __TwigTemplate_062d6142c4cf8d54fc35c567e46f3083 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\ReportBundle\\Scheduler\\Option;

class ExportOption
{
    private int \$reportId;

    /**
     * @param int|null \$reportId
     */
    public function __construct(\$reportId)
    {
        if (!is_null(\$reportId) && !is_numeric(\$reportId)) {
            throw new \\InvalidArgumentException();
        }

        \$this->reportId = (int) \$reportId;
    }

    public function getReportId(): int
    {
        return \$this->reportId;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Scheduler/Option/ExportOption.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Scheduler/Option/ExportOption.php", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Scheduler/Option/ExportOption.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/9c/9cbc109bd797c329128b42dd981af498.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Scheduler/Option/ExportOption.php */
class __TwigTemplate_062d6142c4cf8d54fc35c567e46f3083 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\ReportBundle\\Scheduler\\Option;

class ExportOption
{
    private int \$reportId;

    /**
     * @param int|null \$reportId
     */
    public function __construct(\$reportId)
    {
        if (!is_null(\$reportId) && !is_numeric(\$reportId)) {
            throw new \\InvalidArgumentException();
        }

        \$this->reportId = (int) \$reportId;
    }

    public function getReportId(): int
    {
        return \$this->reportId;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Scheduler/Option/ExportOption.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Scheduler/Option/ExportOption.php", "/var/www/html/production-demo/app/bundles/ReportBundle/Scheduler/Option/ExportOption.php");
    }
}
